<?php

namespace Drupal\recommend_nodes\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'RecommendContentBlock' block.
 *
 * @Block(
 *  id = "recommend_content_block",
 *  admin_label = @Translation("Recommend content block"),
 * )
 */
class RecommendContentBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\Core\Database\Driver\mysql\Connection definition.
   *
   * @var \Drupal\Core\Database\Driver\mysql\Connection
   */
  protected $database;

  /**
   * Drupal\Core\Session\AccountProxyInterface definition.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->database = $container->get('database');
    $instance->currentUser = $container->get('current_user');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    $build['#theme'] = 'recommend_content_block';
    $query = $this->database->select('recommend_nodes', 'nr');
    // Joining with the NODE_INSTRUMENT field table.
    $query->leftjoin('node_field_data', 'n', 'n.nid = nr.nid');
    $query->fields('n', ['title']);
    $query->fields('nr', ['nid']);
    $query->condition('nr.recommend_to', $this->currentUser->id());
    $data = $query->execute()->fetchAll();
    $build['#node_list'] = $data;
    $build['#cache']['max-age'] = 0;
    return $build;
  }

}
